@@ -36,6 +36,7 @@ SPEC_REGIONS = {
     "ap-southeast-1": "https://doigdx0kgq9el.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json",
     "ap-southeast-2": "https://d2stg8d246z9di.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json",
     "ap-southeast-3": "https://cfn-resource-specifications-ap-southeast-3-prod.s3.ap-southeast-3.amazonaws.com/latest/CloudFormationResourceSpecification.json",
+    "ap-southeast-4": "https://cfn-resource-specifications-ap-southeast-4-prod.s3.ap-southeast-4.amazonaws.com/latest/CloudFormationResourceSpecification.json",
     "ca-central-1": "https://d2s8ygphhesbe7.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json",
     "cn-north-1": "https://cfn-resource-specifications-cn-north-1-prod.s3.cn-north-1.amazonaws.com.cn/latest/gzip/CloudFormationResourceSpecification.json",
     "cn-northwest-1": "https://cfn-resource-specifications-cn-northwest-1-prod.s3.cn-northwest-1.amazonaws.com.cn/latest/gzip/CloudFormationResourceSpecification.json",
@@ -206,6 +207,7 @@ VALID_PARAMETER_TYPES_LIST = [
 
 VALID_PARAMETER_TYPES = VALID_PARAMETER_TYPES_SINGLE + VALID_PARAMETER_TYPES_LIST
 
+
 # pylint: disable=missing-class-docstring
 class RegexDict(dict):
     def __getitem__(self, item):
@@ -385,7 +387,6 @@ def set_specs(override_spec_data):
         includes = override_spec_data.pop("IncludeResourceTypes")
 
     for region, spec in RESOURCE_SPECS.items():
-
         # Merge override spec file into the AWS Resource specification
         if override_spec_data:
             RESOURCE_SPECS[region] = merge_spec(override_spec_data, spec)
@@ -446,12 +447,14 @@ def initialize_specs():
     """Reload Resource Specs"""
 
     def load_region(region):
-        spec = load_resource(CloudSpecs, filename=(f"{region}.json"))
+        spec = load_resource(CloudSpecs, filename=f"{region}.json")
 
         for section, section_values in spec.items():
             if section in ["ResourceTypes", "PropertyTypes", "ValueTypes"]:
                 for key, value in section_values.items():
-                    if value == "CACHED":
+                    if value == "CACHED" and RESOURCE_SPECS["us-east-1"][section].get(
+                        key
+                    ):
                         spec[section][key] = RESOURCE_SPECS["us-east-1"][section][key]
         return spec
 
@@ -584,6 +587,6 @@ def override_specs(override_spec_file):
                 "Permission denied when accessing override spec file: %s", filename
             )
             sys.exit(1)
-    except (ValueError) as err:
+    except ValueError as err:
         LOGGER.error("Override spec file %s is malformed: %s", filename, err)
         sys.exit(1)
