@@ -3,23 +3,24 @@ Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
 from __future__ import unicode_literals
+
 import re
-from cfnlint.rules import CloudFormationLintRule
-from cfnlint.rules import RuleMatch
+
+from cfnlint.rules import CloudFormationLintRule, RuleMatch
 
 
 class Used(CloudFormationLintRule):
     """Check if Parameters are used"""
 
-    id = 'W2001'
-    shortdesc = 'Check if Parameters are Used'
-    description = 'Making sure the parameters defined are used'
-    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint'
-    tags = ['parameters']
+    id = "W2001"
+    shortdesc = "Check if Parameters are Used"
+    description = "Making sure the parameters defined are used"
+    source_url = "https://github.com/aws-cloudformation/cfn-python-lint"
+    tags = ["parameters"]
 
     def searchstring(self, string, parameter):
         """Search string for tokenized fields"""
-        regex = re.compile(fr'\${({parameter})}')
+        regex = re.compile(rf"\${({parameter})}")
         return regex.findall(string)
 
     def isparaminref(self, subs, parameter):
@@ -34,8 +35,8 @@ class Used(CloudFormationLintRule):
     def match(self, cfn):
         matches = []
 
-        reftrees = cfn.transform_pre.get('Ref')
-        subtrees = cfn.transform_pre.get('Fn::Sub')
+        reftrees = cfn.transform_pre.get("Ref")
+        subtrees = cfn.transform_pre.get("Fn::Sub")
         refs = []
         for reftree in reftrees:
             refs.append(reftree[-1])
@@ -49,9 +50,9 @@ class Used(CloudFormationLintRule):
         for paramname, _ in cfn.get_parameters().items():
             if paramname not in refs:
                 if paramname not in subs:
-                    message = 'Parameter {0} not used.'
+                    message = "Parameter {0} not used."
                     matches.append(
-                        RuleMatch(['Parameters', paramname], message.format(paramname))
+                        RuleMatch(["Parameters", paramname], message.format(paramname))
                     )
 
         return matches
